GQLRefreshResult class

Value object returned by a successful token refresh operation.

Constructors

GQLRefreshResult({required String accessToken, String? refreshToken, DateTime? expirationDate})
const

Properties

accessToken String
final
expirationDate DateTime?
When the new access token expires. Used by GQLTokenRefreshLink for proactive refresh on the next request.
final
hashCode int
The hash code for this object.
no setterinherited
refreshToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited