onRequest method
Called before the request is forwarded down the link chain.
Return the (possibly modified) Request to continue normally.
Implementation
Future<Request> onRequest(Request request) async => request;
Called before the request is forwarded down the link chain.
Return the (possibly modified) Request to continue normally.
Future<Request> onRequest(Request request) async => request;