GQLInterceptorLink class final
A single GraphQL Link that drives a list of GQLInterceptors through
their GQLInterceptor.onRequest → network → GQLInterceptor.onResponse /
GQLInterceptor.onError lifecycle.
Execution order:
onRequest— interceptors run in list order (first → last)onResponse— interceptors run in list order on every responseonError— interceptors run in list order; the first one that returns a non-nullResponseresolves the error and stops further propagation
Constructors
-
GQLInterceptorLink({required List<
GQLInterceptor> interceptors}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interceptors
→ List<
GQLInterceptor> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
concat(
Link next) → Link -
Adds
nextafter this linkinherited -
dispose(
) → Future< void> -
Can be called to clean up resources
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
Request request, [NextLink? forward]) → Stream< Response> -
A function called when a request reaches this
Link -
route(
LinkRouter route) → Link -
Route requests after this link
inherited
-
split(
bool test(Request request), Link left, [Link right = const PassthroughLink()]) → Link -
Split requests after this link
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited