config/config library
Classes
- GQLAuthProvider
- Contract for providing authentication headers Implement this interface to provide custom auth headers
- GQLConfig
- GQLExceptionParser
- Project-level hook for converting raw link exceptions into GQLExceptions.
- GQLRefreshResult
- Value object returned by a successful token refresh operation.
- GQLTokenRefreshProvider
-
Contract that consumers must implement to enable automatic token refresh
inside
GQLTokenRefreshLink.
Typedefs
-
TokenCallback
= Future<
String?> Function()