GQLTokenRefreshProvider class abstract

Contract that consumers must implement to enable automatic token refresh inside GQLTokenRefreshLink.

The four methods mirror the responsibilities split across

Constructors

GQLTokenRefreshProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getRefreshToken() Future<String?>
getTokenExpirationDate() Future<DateTime?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTokenRefreshed(GQLRefreshResult result) Future<void>
performRefresh(String refreshToken) Future<GQLRefreshResult?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited