GQLInterceptor class abstract
Registered interceptors are run by GQLInterceptorLink in the order they appear in GQLConfig.interceptors.
Constructors
- GQLInterceptor()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
Object error, StackTrace stackTrace, Request request, Future< Response> retry(Request)) → Future<Response?> - Called when the downstream chain throws an exception
-
onRequest(
Request request) → Future< Request> - Called before the request is forwarded down the link chain.
-
onResponse(
Response response, Request request, Future< Response> retry(Request)) → Future<Response> -
Called for each
Responsethat comes back from the network. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited